#include "jnihandler.h"

#include <QAndroidJniEnvironment>
#include <QDebug>
#include <QLibrary>
#include <QAndroidJniObject>

jnihandler *jnihandler::m_instance = nullptr;

jnihandler::jnihandler(QObject *parent) : QObject(parent)
{
    m_instance = this;
}

void jnihandler::getDefaultAdapter()
{
    qDebug(" >> jnihandler::getDefaultAdapter");
    QAndroidJniEnvironment env;
    QAndroidJniObject adapter = QAndroidJniObject::callStaticObjectMethod("android/bluetooth/BluetoothAdapter",
                                              "getDefaultAdapter",
                                              "()Landroid/bluetooth/BluetoothAdapter;");

    if (!adapter.isValid()) {
        if (env->ExceptionCheck()) {
            env->ExceptionDescribe();
            env->ExceptionClear();
        }
        qWarning("jnihandler::initBT, adapter not valid");
        m_logger_text = "jnihandler::initBT, adapter: NOK";
        return;
    }
    m_logger_text = "jnihandler::initBT, adapter: OK" + adapter.toString();
    qDebug() << " << jnihandler::getDefaultAdapter" << adapter.toString();
}

void jnihandler::getDefaultAdapterFromSharedLib()
{
    qDebug(" >> jnihandler::getDefaultAdapterFromSharedLib");

    QLibrary library("qtbug87854bluetoothlib_armeabi-v7a");

    if (!library.load()) {
           qDebug() << library.errorString();
           m_logger_text = library.errorString();
           return;
    }

    if (library.load()) {
       qDebug() << "library loaded";
    }

    typedef QAndroidJniObject *(*getBluetoothAdapter)();
    getBluetoothAdapter getter = (getBluetoothAdapter)library.resolve("getBtAdapter");

    if(getter) {
        QAndroidJniObject *adapter = getter();
        if(adapter->isValid()) {
            qDebug() << "getDefaultAdapterFromSharedLib was valid: " << adapter->toString();
            m_logger_text = "getDefaultAdapterFromSharedLib, OK" + adapter->toString();
        }
    }

    qDebug(" << jnihandler::getDefaultAdapterFromSharedLib");
    library.unload();
}

